@@ -33,7 +33,7 @@ class ZeroShotClassifierParameters(AnnotatorParameters):
                             fine-tuned on Multi-Genre Natural Language Inference (MNLI) dataset for the
                             zero-shot classification task. The model is not case-sensitive, i.e., it does not
                             make a difference between "english" and "English".
-                            <li>`BaptisteDoyen/camembert-base-xnli`: Camembert-base model fine-tuned on french
+                            <li>`BaptisteDoyen/camembert-base-xlni`: Camembert-base model fine-tuned on french
                             part of XNLI dataset.""")
     processing_unit: ProcessingUnit = Field(ProcessingUnit.document,
                                             description="""The processing unit to apply the classification in the input
